# -*- coding: UTF-8 -*-
'''
@Author  ：程序员晚枫，B站/抖音/微博/小红书/公众号
@WeChat     ：CoderWanFeng
@Blog      ：www.python-office.com
@Date    ：2023/2/8 23:39
@Description     ：
'''
from poai.api import chatgpt
from poai.api import aiart
from poai.api import chat
# from poai.lib.Const import SPLIT_LINE
#
# print(SPLIT_LINE)
# print('【poai库】，功能持续更新中')
# print('使用有问题 or 提交你的功能需求 or 参与项目开发')
# print('1、请+【项目交流群】：http://www.python4office.cn/wechat-group/')
# print('2、本开源项目的【代码仓库】：https://github.com/CoderWanFeng/poai')
# print('3、免费的微信机器人：https://mp.weixin.qq.com/s/9aspEHdCiAdXK17AvHlu9Q')
# print(SPLIT_LINE)